summaryrefslogtreecommitdiffstats
path: root/mpvcore
diff options
context:
space:
mode:
authorAlessandro Ghedini <alessandro@ghedini.me>2013-10-16 12:36:34 +0200
committerwm4 <wm4@nowhere>2013-10-20 14:10:43 +0200
commit2cf8d4ffdb302dbb43d3eff9f80d6b18c48fcaee (patch)
treec09bc4734242174aad6812541d5187de569e4560 /mpvcore
parente6236e22db85b45dffecb6ce55959829111fed03 (diff)
downloadmpv-2cf8d4ffdb302dbb43d3eff9f80d6b18c48fcaee.tar.bz2
mpv-2cf8d4ffdb302dbb43d3eff9f80d6b18c48fcaee.tar.xz
spelling fixes
Diffstat (limited to 'mpvcore')
-rw-r--r--mpvcore/lua/osc.lua6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpvcore/lua/osc.lua b/mpvcore/lua/osc.lua
index f908a23c54..c724c7737c 100644
--- a/mpvcore/lua/osc.lua
+++ b/mpvcore/lua/osc.lua
@@ -52,7 +52,7 @@ local osc_styles = {
-- internal states, do not touch
local state = {
- showtime, -- time of last invokation (last mouse move)
+ showtime, -- time of last invocation (last mouse move)
osc_visible = false,
anistart, -- time when the animation started
anitype, -- current type of animation
@@ -636,7 +636,7 @@ function osc_init()
-- kill old Elements
elements = {}
- -- set canvas resolution acording to display aspect and scaling setting
+ -- set canvas resolution according to display aspect and scaling setting
local baseResY = 720
local display_w, display_h, display_aspect = mp.get_screen_size()
local scale = 1
@@ -999,7 +999,7 @@ end
function show_osc()
- --remember last time of invokation (mouse move)
+ --remember last time of invocation (mouse move)
state.showtime = mp.get_timer()
state.osc_visible = true